@@ -2,7 +2,8 @@
 # pylint: disable=C0103,W0622
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015 Leandro Toledo de Souza <devs@python-telegram-bot.org>
+# Copyright (C) 2015-2016
+# Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser Public License as published by
@@ -16,8 +17,7 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
-"""This module contains a object that represents a Telegram Chat"""
+"""This module contains a object that represents a Telegram Chat."""
 
 from telegram import TelegramObject
 
@@ -42,10 +42,7 @@ class Chat(TelegramObject):
         type (Optional[str]):
     """
 
-    def __init__(self,
-                 id,
-                 type,
-                 **kwargs):
+    def __init__(self, id, type, **kwargs):
         # Required
         self.id = int(id)
         self.type = type
