@@ -16,8 +16,6 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
-
 """This module contains the class Updater, which tries to make creating
 Telegram bots intuitive."""
 
@@ -85,8 +83,7 @@ class Updater(object):
         self.update_queue = Queue()
         self.job_queue = JobQueue(self.bot, job_queue_tick_interval)
         self.__exception_event = Event()
-        self.dispatcher = Dispatcher(self.bot, self.update_queue, workers,
-                                     self.__exception_event)
+        self.dispatcher = Dispatcher(self.bot, self.update_queue, workers, self.__exception_event)
         self.last_update_id = 0
         self.logger = logging.getLogger(__name__)
         self.running = False
@@ -96,8 +93,28 @@ class Updater(object):
         self.__threads = []
         """:type: list[Thread]"""
 
-    def start_polling(self, poll_interval=0.0, timeout=10, network_delay=2,
-                      clean=False, bootstrap_retries=0):
+    def _init_thread(self, target, name, *args, **kwargs):
+        thr = Thread(target=self._thread_wrapper, name=name, args=(target,) + args, kwargs=kwargs)
+        thr.start()
+        self.__threads.append(thr)
+
+    def _thread_wrapper(self, target, *args, **kwargs):
+        thr_name = current_thread().name
+        self.logger.debug('{0} - started'.format(thr_name))
+        try:
+            target(*args, **kwargs)
+        except Exception:
+            self.__exception_event.set()
+            self.logger.exception('unhandled exception')
+            raise
+        self.logger.debug('{0} - ended'.format(thr_name))
+
+    def start_polling(self,
+                      poll_interval=0.0,
+                      timeout=10,
+                      network_delay=2,
+                      clean=False,
+                      bootstrap_retries=0):
         """
         Starts polling updates from Telegram.
 
@@ -123,35 +140,15 @@ class Updater(object):
         with self.__lock:
             if not self.running:
                 self.running = True
-                if clean:
-                    self._clean_updates()
 
                 # Create & start threads
                 self._init_thread(self.dispatcher.start, "dispatcher")
-                self._init_thread(self._start_polling, "updater",
-                                  poll_interval, timeout, network_delay,
-                                  bootstrap_retries)
+                self._init_thread(self._start_polling, "updater", poll_interval, timeout,
+                                  network_delay, bootstrap_retries, clean)
 
                 # Return the update queue so the main thread can insert updates
                 return self.update_queue
 
-    def _init_thread(self, target, name, *args, **kwargs):
-        thr = Thread(target=self._thread_wrapper, name=name,
-                     args=(target,) + args, kwargs=kwargs)
-        thr.start()
-        self.__threads.append(thr)
-
-    def _thread_wrapper(self, target, *args, **kwargs):
-        thr_name = current_thread().name
-        self.logger.debug('{0} - started'.format(thr_name))
-        try:
-            target(*args, **kwargs)
-        except Exception:
-            self.__exception_event.set()
-            self.logger.exception('unhandled exception')
-            raise
-        self.logger.debug('{0} - ended'.format(thr_name))
-
     def start_webhook(self,
                       listen='127.0.0.1',
                       port=80,
@@ -194,20 +191,16 @@ class Updater(object):
         with self.__lock:
             if not self.running:
                 self.running = True
-                if clean:
-                    self._clean_updates()
 
                 # Create & start threads
                 self._init_thread(self.dispatcher.start, "dispatcher"),
-                self._init_thread(self._start_webhook, "updater", listen,
-                                  port, url_path, cert, key, bootstrap_retries,
-                                  webhook_url)
+                self._init_thread(self._start_webhook, "updater", listen, port, url_path, cert,
+                                  key, bootstrap_retries, clean, webhook_url)
 
                 # Return the update queue so the main thread can insert updates
                 return self.update_queue
 
-    def _start_polling(self, poll_interval, timeout, network_delay,
-                       bootstrap_retries):
+    def _start_polling(self, poll_interval, timeout, network_delay, bootstrap_retries, clean):
         """
         Thread target of thread 'updater'. Runs in background, pulls
         updates from Telegram and inserts them in the update queue of the
@@ -217,7 +210,7 @@ class Updater(object):
         cur_interval = poll_interval
         self.logger.debug('Updater thread started')
 
-        self._set_webhook(None, bootstrap_retries, None)
+        self._bootstrap(bootstrap_retries, clean=clean, webhook_url='')
 
         while self.running:
             try:
@@ -225,8 +218,7 @@ class Updater(object):
                                               timeout=timeout,
                                               network_delay=network_delay)
             except TelegramError as te:
-                self.logger.error(
-                    "Error while getting Updates: {0}".format(te))
+                self.logger.error("Error while getting Updates: {0}".format(te))
 
                 # Put the error into the update queue and let the Dispatcher
                 # broadcast it
@@ -249,28 +241,6 @@ class Updater(object):
 
             sleep(cur_interval)
 
-    def _set_webhook(self, webhook_url, max_retries, cert):
-        retries = 0
-        while 1:
-            try:
-                # Remove webhook
-                self.bot.setWebhook(webhook_url=webhook_url,
-                                    certificate=cert)
-            except (Unauthorized, InvalidToken):
-                raise
-            except TelegramError:
-                msg = 'failed to set webhook; try={0} max_retries={1}'.format(
-                    retries, max_retries)
-                if max_retries < 0 or retries < max_retries:
-                    self.logger.info(msg)
-                    retries += 1
-                else:
-                    self.logger.exception(msg)
-                    raise
-            else:
-                break
-            sleep(1)
-
     @staticmethod
     def _increase_poll_interval(current_interval):
         # increase waiting times on subsequent errors up to 30secs
@@ -282,16 +252,15 @@ class Updater(object):
             current_interval = 30
         return current_interval
 
-    def _start_webhook(self, listen, port, url_path, cert, key,
-                       bootstrap_retries, webhook_url):
+    def _start_webhook(self, listen, port, url_path, cert, key, bootstrap_retries, clean,
+                       webhook_url):
         self.logger.debug('Updater thread started')
         use_ssl = cert is not None and key is not None
         if not url_path.startswith('/'):
             url_path = '/{0}'.format(url_path)
 
         # Create and start server
-        self.httpd = WebhookServer((listen, port), WebhookHandler,
-                                   self.update_queue, url_path)
+        self.httpd = WebhookServer((listen, port), WebhookHandler, self.update_queue, url_path)
 
         if use_ssl:
             self._check_ssl_cert(cert, key)
@@ -300,18 +269,23 @@ class Updater(object):
             if not webhook_url:
                 webhook_url = self._gen_webhook_url(listen, port, url_path)
 
-            self._set_webhook(webhook_url, bootstrap_retries,
-                              open(cert, 'rb'))
+            self._bootstrap(max_retries=bootstrap_retries,
+                            clean=clean,
+                            webhook_url=webhook_url,
+                            cert=open(cert, 'rb'))
+        elif clean:
+            self.logger.warning("cleaning updates is not supported if "
+                                "SSL-termination happens elsewhere; skipping")
 
         self.httpd.serve_forever(poll_interval=1)
 
     def _check_ssl_cert(self, cert, key):
         # Check SSL-Certificate with openssl, if possible
         try:
-            exit_code = subprocess.call(["openssl", "x509", "-text",
-                                         "-noout", "-in", cert],
-                                        stdout=open(os.devnull, 'wb'),
-                                        stderr=subprocess.STDOUT)
+            exit_code = subprocess.call(
+                ["openssl", "x509", "-text", "-noout", "-in", cert],
+                stdout=open(os.devnull, 'wb'),
+                stderr=subprocess.STDOUT)
         except OSError:
             exit_code = 0
         if exit_code is 0:
@@ -326,11 +300,35 @@ class Updater(object):
         else:
             raise TelegramError('SSL Certificate invalid')
 
-    def _gen_webhook_url(self, listen, port, url_path):
-        return 'https://{listen}:{port}{path}'.format(
-            listen=listen,
-            port=port,
-            path=url_path)
+    @staticmethod
+    def _gen_webhook_url(listen, port, url_path):
+        return 'https://{listen}:{port}{path}'.format(listen=listen, port=port, path=url_path)
+
+    def _bootstrap(self, max_retries, clean, webhook_url, cert=None):
+        retries = 0
+        while True:
+
+            try:
+                if clean:
+                    # Disable webhook for cleaning
+                    self.bot.setWebhook(webhook_url='')
+                    self._clean_updates()
+
+                self.bot.setWebhook(webhook_url=webhook_url, certificate=cert)
+            except (Unauthorized, InvalidToken):
+                raise
+            except TelegramError:
+                msg = 'error in bootstrap phase; try={0} max_retries={1}'\
+                        .format(retries, max_retries)
+                if max_retries < 0 or retries < max_retries:
+                    self.logger.warning(msg)
+                    retries += 1
+                else:
+                    self.logger.exception(msg)
+                    raise
+            else:
+                break
+            sleep(1)
 
     def _clean_updates(self):
         self.logger.debug('Cleaning updates from Telegram server')
@@ -360,10 +358,9 @@ class Updater(object):
 
     def _stop_httpd(self):
         if self.httpd:
-            self.logger.debug(
-                'Waiting for current webhook connection to be '
-                'closed... Send a Telegram message to the bot to exit '
-                'immediately.')
+            self.logger.debug('Waiting for current webhook connection to be '
+                              'closed... Send a Telegram message to the bot to exit '
+                              'immediately.')
             self.httpd.shutdown()
             self.httpd = None
 
@@ -376,16 +373,13 @@ class Updater(object):
             threads = list(dispatcher.async_threads)
         total = len(threads)
         for i, thr in enumerate(threads):
-            self.logger.debug(
-                'Waiting for async thread {0}/{1} to end'.format(i, total))
+            self.logger.debug('Waiting for async thread {0}/{1} to end'.format(i, total))
             thr.join()
-            self.logger.debug(
-                'async thread {0}/{1} has ended'.format(i, total))
+            self.logger.debug('async thread {0}/{1} has ended'.format(i, total))
 
     def _join_threads(self):
         for thr in self.__threads:
-            self.logger.debug(
-                'Waiting for {0} thread to end'.format(thr.name))
+            self.logger.debug('Waiting for {0} thread to end'.format(thr.name))
             thr.join()
             self.logger.debug('{0} thread has ended'.format(thr.name))
         self.__threads = []
