@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# pylint: disable=no-name-in-module,unused-import
 #
 # A library that provides a Python interface to the Telegram Bot API
 # Copyright (C) 2015-2016
@@ -17,7 +16,6 @@
 #
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
-
 """This module contains methods to make POST and GET requests"""
 
 import functools
@@ -25,22 +23,9 @@ import json
 import socket
 from ssl import SSLError
 
-try:
-    # python2
-    from httplib import HTTPException
-except ImportError:
-    # python3
-    from http.client import HTTPException
-
-try:
-    # python3
-    from urllib.request import urlopen, urlretrieve, Request
-    from urllib.error import HTTPError, URLError
-except ImportError:
-    # python2
-    from urllib import urlretrieve
-    from urllib2 import urlopen, Request, URLError
-    from urllib2 import HTTPError
+from future.moves.http.client import HTTPException
+from future.moves.urllib.error import HTTPError, URLError
+from future.moves.urllib.request import urlopen, urlretrieve, Request
 
 from telegram import (InputFile, TelegramError)
 from telegram.error import Unauthorized, NetworkError, TimedOut
@@ -71,6 +56,7 @@ def _parse(json_data):
 
 def _try_except_req(func):
     """Decorator for requests to handle known exceptions"""
+
     @functools.wraps(func)
     def decorator(*args, **kwargs):
         try:
@@ -83,7 +69,7 @@ def _try_except_req(func):
 
             if errcode in (401, 403):
                 raise Unauthorized()
-            if errcode == 502:
+            elif errcode == 502:
                 raise NetworkError('Bad Gateway')
 
             try:
@@ -106,6 +92,9 @@ def _try_except_req(func):
         except HTTPException as error:
             raise NetworkError('HTTPException: {0!r}'.format(error))
 
+        except socket.error as error:
+            raise NetworkError('socket.error: {0!r}'.format(error))
+
     return decorator
 
 
@@ -125,10 +114,7 @@ def get(url):
 
 
 @_try_except_req
-def post(url,
-         data,
-         timeout=None,
-         network_delay=2.):
+def post(url, data, timeout=None):
     """Request an URL.
     Args:
       url:
@@ -138,11 +124,6 @@ def post(url,
       timeout:
         float. If this value is specified, use it as the definitive timeout (in
         seconds) for urlopen() operations. [Optional]
-      network_delay:
-        float. If using the timeout specified in `data` (which is a timeout for
-        the Telegram servers operation), then `network_delay` as an extra delay
-        (in seconds) to compensate for network latency.
-        default: 2 [Optional]
 
     Notes:
       If neither `timeout` nor `data['timeout']` is specified. The underlying
@@ -156,34 +137,27 @@ def post(url,
 
     if timeout is not None:
         urlopen_kwargs['timeout'] = timeout
-    elif 'timeout' in data:
-        urlopen_kwargs['timeout'] = data['timeout'] + network_delay
 
     if InputFile.is_inputfile(data):
         data = InputFile(data)
-        request = Request(url,
-                          data=data.to_form(),
-                          headers=data.headers)
+        request = Request(url, data=data.to_form(), headers=data.headers)
     else:
         data = json.dumps(data)
-        request = Request(url,
-                          data=data.encode(),
-                          headers={'Content-Type': 'application/json'})
+        request = Request(url, data=data.encode(), headers={'Content-Type': 'application/json'})
 
     result = urlopen(request, **urlopen_kwargs).read()
     return _parse(result)
 
 
 @_try_except_req
-def download(url,
-             filename):
+def download(url, filename):
     """Download a file by its URL.
     Args:
       url:
         The web location we want to retrieve.
 
       filename:
-        The filename wihtin the path to download the file.
+        The filename within the path to download the file.
     """
 
     urlretrieve(url, filename)
